package com.bonus.hn.bearing.capacity.backstage.ownteam.dao;

import com.bonus.hn.bearing.capacity.backstage.companypro.entity.TreeBean;
import com.bonus.hn.bearing.capacity.backstage.ownteam.entity.OwnTeamManageBean;
import com.bonus.hn.bearing.capacity.backstage.select.entity.SelectBean;
import org.springframework.stereotype.Repository;

import java.util.List;

/**
 * 包名称：com.bonus.hn.bearing.capacity.backstage.companypro.dao
 * 类名称：ProjectManagerDao
 * 类描述：
 * 创建人：@author xxxxxx
 * 创建时间：2023年11月06日 16:26
 */
@Repository(value = "OwnTeamManageDao")
public interface OwnTeamManageDao {
    List<OwnTeamManageBean> getOwnTeamsList(OwnTeamManageBean o);

    List<SelectBean> getBranchName(SelectBean o);

    List<SelectBean> getVoltageLevel(SelectBean o);

    List<SelectBean> getProName(SelectBean o);

    List<SelectBean> getTeamType(SelectBean o);

    List<OwnTeamManageBean> getProjectManagementTeamsFormList(OwnTeamManageBean o);

    List<OwnTeamManageBean> getProManageTeamNum(OwnTeamManageBean o);

    int determineIfExists(OwnTeamManageBean bean);

    int addProManageTeam(OwnTeamManageBean bean);

    int updateProManageTeam(OwnTeamManageBean bean);

    int insertProManageTeam(OwnTeamManageBean bean);

    void updateProManage(OwnTeamManageBean bean);

    int delOwnTeamById(OwnTeamManageBean bean);

    List<TreeBean> getCompanyProTree(TreeBean o);

    List<OwnTeamManageBean> getTeamsList(OwnTeamManageBean o);

    int bindProTeam(OwnTeamManageBean bean);

    int unBindProTeam(OwnTeamManageBean bean);

    int updateStatus(OwnTeamManageBean bean);

    int delProTeamPersonById(OwnTeamManageBean bean);

    String getProIdByOwnId(OwnTeamManageBean bean);

    List<OwnTeamManageBean> getOwnPersonList(OwnTeamManageBean o);

    int updateOwnTeamStatus(OwnTeamManageBean bean);
}
